# UniRef-to-GO maps

[Gene Ontology](https://geneontology.org/) (**GO**) is a classification system for gene functions. All GO terms can be traced to three top categories: **biological process**, **cellular component**, and **molecular function**. **GO slim** is a set of higher-level categories of GO terms.
